<?php
session_start();
require_once 'config.php';

try {
    $pdo = new PDO('mysql:host=' . DB_HOST . ';dbname=' . DB_NAME, DB_USER, DB_PASS);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    $_SESSION['message'] = "<div class='alert alert-danger'>خطا در اتصال به پایگاه داده: " . $e->getMessage() . "</div>";
    header("Location: admin.php");
    exit;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';
    if ($action === 'add_main_button') {
        $title = trim($_POST['title'] ?? '');
        if (!empty($title)) {
            $stmt = $pdo->prepare("INSERT INTO main_buttons (title) VALUES (:title)");
            if ($stmt->execute([':title' => $title])) {
                $_SESSION['message'] = "<div class='alert alert-success'>دکمه اصلی با موفقیت اضافه شد.</div>";
            } else {
                $_SESSION['message'] = "<div class='alert alert-danger'>خطا در افزودن دکمه اصلی.</div>";
            }
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>عنوان دکمه اصلی نمی‌تواند خالی باشد.</div>";
        }
        header("Location: admin.php");
        exit;
    } elseif ($action === 'edit_main_button') {
        $id = intval($_POST['id'] ?? 0);
        $title = trim($_POST['title'] ?? '');
        if ($id > 0 && !empty($title)) {
            $stmt = $pdo->prepare("UPDATE main_buttons SET title = :title WHERE id = :id");
            if ($stmt->execute([':title' => $title, ':id' => $id])) {
                $_SESSION['message'] = "<div class='alert alert-success'>دکمه اصلی با موفقیت ویرایش شد.</div>";
            } else {
                $_SESSION['message'] = "<div class='alert alert-danger'>خطا در ویرایش دکمه اصلی.</div>";
            }
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>اطلاعات وارد شده نامعتبر است.</div>";
        }
        header("Location: admin.php");
        exit;
    } elseif ($action === 'add_inline_button') {
        $main_button_id = intval($_POST['main_button_id'] ?? 0);
        $inline_title = trim($_POST['inline_title'] ?? '');
        $description = trim($_POST['description'] ?? '');
        if ($main_button_id > 0 && !empty($inline_title)) {
            $stmt = $pdo->prepare("INSERT INTO inline_buttons (main_button_id, title, description) VALUES (:mbid, :title, :description)");
            if ($stmt->execute([':mbid' => $main_button_id, ':title' => $inline_title, ':description' => $description])) {
                $_SESSION['message'] = "<div class='alert alert-success'>دکمه اینلاین با موفقیت اضافه شد.</div>";
            } else {
                $_SESSION['message'] = "<div class='alert alert-danger'>خطا در افزودن دکمه اینلاین.</div>";
            }
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>عنوان دکمه اینلاین نمی‌تواند خالی باشد.</div>";
        }
        header("Location: admin.php");
        exit;
    } elseif ($action === 'edit_inline_button') {
        $id = intval($_POST['id'] ?? 0);
        $inline_title = trim($_POST['inline_title'] ?? '');
        $description = trim($_POST['description'] ?? '');
        if ($id > 0 && !empty($inline_title)) {
            $stmt = $pdo->prepare("UPDATE inline_buttons SET title = :title, description = :description WHERE id = :id");
            if ($stmt->execute([':title' => $inline_title, ':description' => $description, ':id' => $id])) {
                $_SESSION['message'] = "<div class='alert alert-success'>دکمه اینلاین با موفقیت ویرایش شد.</div>";
            } else {
                $_SESSION['message'] = "<div class='alert alert-danger'>خطا در ویرایش دکمه اینلاین.</div>";
            }
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>اطلاعات وارد شده نامعتبر است.</div>";
        }
        header("Location: admin.php");
        exit;
    } elseif ($action === 'upload_file') {
        $inline_button_id = intval($_POST['inline_button_id'] ?? 0);
        $file_type = $_POST['file_type'] ?? '';
        $caption = trim($_POST['caption'] ?? '');
        if ($inline_button_id > 0 && isset($_FILES['file']) && $_FILES['file']['error'] == UPLOAD_ERR_OK) {
            $uploadDir = __DIR__ . '/uploads/';
            if (!is_dir($uploadDir)) {
                mkdir($uploadDir, 0777, true);
            }
            $fileName = basename($_FILES['file']['name']);
            $targetFile = $uploadDir . time() . "_" . $fileName;
            if (move_uploaded_file($_FILES['file']['tmp_name'], $targetFile)) {
                $stmt = $pdo->prepare("INSERT INTO files (inline_button_id, file_type, file_path, caption) VALUES (:ibid, :ftype, :fpath, :caption)");
                if ($stmt->execute([':ibid' => $inline_button_id, ':ftype' => $file_type, ':fpath' => $targetFile, ':caption' => $caption])) {
                    $_SESSION['message'] = "<div class='alert alert-success'>فایل با موفقیت آپلود شد.</div>";
                } else {
                    $_SESSION['message'] = "<div class='alert alert-danger'>خطا در ذخیره اطلاعات فایل.</div>";
                }
            } else {
                $_SESSION['message'] = "<div class='alert alert-danger'>خطا در آپلود فایل.</div>";
            }
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>اطلاعات فایل وارد شده نامعتبر است.</div>";
        }
        header("Location: admin.php");
        exit;
    } elseif ($action === 'edit_file') {
        $id = intval($_POST['id'] ?? 0);
        $caption = trim($_POST['caption'] ?? '');
        if ($id > 0) {
            $stmt = $pdo->prepare("UPDATE files SET caption = :caption WHERE id = :id");
            if ($stmt->execute([':caption' => $caption, ':id' => $id])) {
                $_SESSION['message'] = "<div class='alert alert-success'>فایل با موفقیت ویرایش شد.</div>";
            } else {
                $_SESSION['message'] = "<div class='alert alert-danger'>خطا در ویرایش فایل.</div>";
            }
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>اطلاعات فایل وارد شده نامعتبر است.</div>";
        }
        header("Location: admin.php");
        exit;
    } else {
         $_SESSION['message'] = "<div class='alert alert-danger'>عملیات نامعتبر.</div>";
         header("Location: admin.php");
         exit;
    }
} elseif ($_SERVER['REQUEST_METHOD'] === 'GET') {
    $action = $_GET['action'] ?? '';
    if ($action === 'delete_main_button') {
         $id = intval($_GET['id'] ?? 0);
         if ($id > 0) {
             $stmt = $pdo->prepare("DELETE FROM main_buttons WHERE id = :id");
             if ($stmt->execute([':id' => $id])) {
                 $_SESSION['message'] = "<div class='alert alert-success'>دکمه اصلی با موفقیت حذف شد.</div>";
             } else {
                 $_SESSION['message'] = "<div class='alert alert-danger'>خطا در حذف دکمه اصلی.</div>";
             }
         } else {
             $_SESSION['message'] = "<div class='alert alert-danger'>شناسه نامعتبر.</div>";
         }
         header("Location: admin.php");
         exit;
    } elseif ($action === 'delete_inline_button') {
         $id = intval($_GET['id'] ?? 0);
         if ($id > 0) {
             $stmt = $pdo->prepare("DELETE FROM inline_buttons WHERE id = :id");
             if ($stmt->execute([':id' => $id])) {
                 $_SESSION['message'] = "<div class='alert alert-success'>دکمه اینلاین با موفقیت حذف شد.</div>";
             } else {
                 $_SESSION['message'] = "<div class='alert alert-danger'>خطا در حذف دکمه اینلاین.</div>";
             }
         } else {
             $_SESSION['message'] = "<div class='alert alert-danger'>شناسه نامعتبر.</div>";
         }
         header("Location: admin.php");
         exit;
    } elseif ($action === 'delete_file') {
         $id = intval($_GET['id'] ?? 0);
         if ($id > 0) {
             $stmt = $pdo->prepare("SELECT file_path FROM files WHERE id = :id");
             $stmt->execute([':id' => $id]);
             $file = $stmt->fetch(PDO::FETCH_ASSOC);
             if ($file && file_exists($file['file_path'])) {
                 unlink($file['file_path']);
             }
             $stmt = $pdo->prepare("DELETE FROM files WHERE id = :id");
             if ($stmt->execute([':id' => $id])) {
                 $_SESSION['message'] = "<div class='alert alert-success'>فایل با موفقیت حذف شد.</div>";
             } else {
                 $_SESSION['message'] = "<div class='alert alert-danger'>خطا در حذف فایل.</div>";
             }
         } else {
             $_SESSION['message'] = "<div class='alert alert-danger'>شناسه نامعتبر.</div>";
         }
         header("Location: admin.php");
         exit;
    } elseif ($action === 'toggle_user') {
         $id = intval($_GET['id'] ?? 0);
         $toggle = $_GET['toggle'] ?? '';
         if ($id > 0) {
             if ($toggle === 'block') {
                 $stmt = $pdo->prepare("UPDATE users SET status = 'blocked' WHERE id = :id");
             } elseif ($toggle === 'unblock') {
                 $stmt = $pdo->prepare("UPDATE users SET status = 'active' WHERE id = :id");
             } else {
                 $_SESSION['message'] = "<div class='alert alert-danger'>عملیات نامعتبر.</div>";
                 header("Location: admin.php");
                 exit;
             }
             if ($stmt->execute([':id' => $id])) {
                 $_SESSION['message'] = "<div class='alert alert-success'>وضعیت کاربر با موفقیت به‌روزرسانی شد.</div>";
             } else {
                 $_SESSION['message'] = "<div class='alert alert-danger'>خطا در به‌روزرسانی وضعیت کاربر.</div>";
             }
         } else {
             $_SESSION['message'] = "<div class='alert alert-danger'>شناسه نامعتبر.</div>";
         }
         header("Location: admin.php");
         exit;
    } elseif ($action === 'approve_suggested') {
         $id = intval($_GET['id'] ?? 0);
         if ($id > 0) {
             $stmt = $pdo->prepare("UPDATE suggested_files SET status = 'approved' WHERE id = :id");
             if ($stmt->execute([':id' => $id])) {
                 // ارسال پیام به کاربر جهت اطلاع از تایید فایل پیشنهادی
                 $stmtUser = $pdo->prepare("SELECT telegram_id FROM users WHERE id = (SELECT user_id FROM suggested_files WHERE id = :id LIMIT 1)");
                 $stmtUser->execute([':id' => $id]);
                 $user = $stmtUser->fetch(PDO::FETCH_ASSOC);
                 if ($user) {
                     require_once 'telegram_api.php';
                     sendMessage($user['telegram_id'], "فایل پیشنهادی شما تایید شد.");
                 }
                 $_SESSION['message'] = "<div class='alert alert-success'>فایل پیشنهادی تایید شد.</div>";
             } else {
                 $_SESSION['message'] = "<div class='alert alert-danger'>خطا در تایید فایل پیشنهادی.</div>";
             }
         } else {
             $_SESSION['message'] = "<div class='alert alert-danger'>شناسه نامعتبر.</div>";
         }
         header("Location: admin.php");
         exit;
    } elseif ($action === 'reject_suggested') {
         $id = intval($_GET['id'] ?? 0);
         if ($id > 0) {
             $stmt = $pdo->prepare("UPDATE suggested_files SET status = 'rejected' WHERE id = :id");
             if ($stmt->execute([':id' => $id])) {
                 $stmtUser = $pdo->prepare("SELECT telegram_id FROM users WHERE id = (SELECT user_id FROM suggested_files WHERE id = :id LIMIT 1)");
                 $stmtUser->execute([':id' => $id]);
                 $user = $stmtUser->fetch(PDO::FETCH_ASSOC);
                 if ($user) {
                     require_once 'telegram_api.php';
                     sendMessage($user['telegram_id'], "فایل پیشنهادی شما رد شد.");
                 }
                 $_SESSION['message'] = "<div class='alert alert-success'>فایل پیشنهادی رد شد.</div>";
             } else {
                 $_SESSION['message'] = "<div class='alert alert-danger'>خطا در رد فایل پیشنهادی.</div>";
             }
         } else {
             $_SESSION['message'] = "<div class='alert alert-danger'>شناسه نامعتبر.</div>";
         }
         header("Location: admin.php");
         exit;
    } else {
         $_SESSION['message'] = "<div class='alert alert-danger'>عملیات نامعتبر.</div>";
         header("Location: admin.php");
         exit;
    }
} else {
    $_SESSION['message'] = "<div class='alert alert-danger'>درخواست نامعتبر.</div>";
    header("Location: admin.php");
    exit;
}
?>
