<?php
// bot.php
require_once 'config.php';
require_once 'telegram_api.php';

// اتصال به پایگاه داده
try {
    $pdo = new PDO('mysql:host=' . DB_HOST . ';dbname=' . DB_NAME, DB_USER, DB_PASS);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    error_log("خطا در اتصال به پایگاه داده: " . $e->getMessage());
    exit;
}

// دریافت آپدیت از تلگرام
$content = file_get_contents("php://input");
$update = json_decode($content, true);
if (!$update) {
    exit;
}

/* 
  اگر کاربر دستور /suggest ارسال کند، یک پیام دعوت به ارسال فایل پیشنهادی نمایش داده می‌شود.
  همچنین اگر پیام شامل یک فایل (document, video, audio) باشد و در کپشن آن "/suggest" نوشته شده باشد،
  آن فایل به عنوان فایل پیشنهادی ثبت می‌شود.
*/

if (isset($update['message'])) {
    $message = $update['message'];
    $chat_id = $message['chat']['id'];
    $text = isset($message['text']) ? trim($message['text']) : '';

    // استخراج اطلاعات کاربر از قسمت 'from'
    $from = $message['from'];
    $username = isset($from['username']) ? $from['username'] : '';
    $full_name = trim(($from['first_name'] ?? '') . ' ' . ($from['last_name'] ?? ''));

    // مدیریت کاربران: ثبت یا به‌روزرسانی کاربر (با ذخیره username و full_name)
    $stmt = $pdo->prepare("SELECT * FROM users WHERE telegram_id = :telegram_id LIMIT 1");
    $stmt->execute([':telegram_id' => $chat_id]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($user) {
        if ($user['status'] == 'blocked') {
            sendMessage($chat_id, "متأسفانه شما مسدود شده‌اید.");
            exit;
        }
        // به‌روزرسانی زمان آخرین استفاده و اطلاعات کاربری
        $stmtUpdate = $pdo->prepare("UPDATE users SET last_usage = NOW(), username = :username, full_name = :full_name WHERE id = :id");
        $stmtUpdate->execute([':username' => $username, ':full_name' => $full_name, ':id' => $user['id']]);
    } else {
        // ثبت کاربر جدید
        $stmtInsert = $pdo->prepare("INSERT INTO users (telegram_id, username, full_name) VALUES (:telegram_id, :username, :full_name)");
        $stmtInsert->execute([':telegram_id' => $chat_id, ':username' => $username, ':full_name' => $full_name]);
    }

    // اگر دستور /suggest ارسال شد، پیام دعوت به ارسال فایل پیشنهادی نمایش داده شود.
    if ($text === '/suggest') {
        sendMessage($chat_id, "لطفاً فایل پیشنهادی خود را ارسال نمایید. در کپشن فایل، دستور /suggest را درج کنید.");
        exit;
    }
    
    // اگر پیام شامل فایل پیشنهادی باشد (و در کپشن آن "/suggest" نوشته شده باشد)
    if ((isset($message['document']) || isset($message['video']) || isset($message['audio'])) && isset($message['caption'])) {
        if (strpos($message['caption'], '/suggest') !== false) {
            // ثبت فایل پیشنهادی در جدول suggested_files
            // برای مثال، برای سند، فایل_id را ذخیره می‌کنیم؛ برای سایر موارد مشابه عمل کنید.
            $file_id = "";
            if (isset($message['document'])) {
                $file_id = $message['document']['file_id'];
            } elseif (isset($message['video'])) {
                $file_id = $message['video']['file_id'];
            } elseif (isset($message['audio'])) {
                $file_id = $message['audio']['file_id'];
            }
            // اطمینان از وجود کاربر (قبلاً ثبت شده است)
            $stmt = $pdo->prepare("SELECT id FROM users WHERE telegram_id = :telegram_id LIMIT 1");
            $stmt->execute([':telegram_id' => $chat_id]);
            $user = $stmt->fetch(PDO::FETCH_ASSOC);
            $user_id = $user ? $user['id'] : $pdo->lastInsertId();
            $stmt = $pdo->prepare("INSERT INTO suggested_files (user_id, file_url) VALUES (:user_id, :file_url)");
            if ($stmt->execute([':user_id' => $user_id, ':file_url' => $file_id])) {
                sendMessage($chat_id, "فایل پیشنهادی شما با موفقیت ثبت شد.");
            } else {
                sendMessage($chat_id, "خطا در ثبت فایل پیشنهادی. لطفاً مجدداً تلاش کنید.");
            }
            exit;
        }
    }

    // پردازش سایر پیام‌ها:
    if ($text === '/start') {
        $welcomeText = "سلام و خوش آمدید به ربات آموزشی ما.\n\n" .
                       "لطفاً از منوی زیر یکی از دسته‌های آموزشی را انتخاب نمایید.";
        
        // واکشی دکمه‌های اصلی از پایگاه داده
        $stmt = $pdo->query("SELECT * FROM main_buttons ORDER BY title");
        $keyboardButtons = [];
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $keyboardButtons[] = $row['title'];
        }
        // تقسیم دکمه‌ها به ردیف‌های چندتایی (مثلاً 3 در هر ردیف)
        $keyboard = [];
        $row = [];
        $i = 0;
        foreach ($keyboardButtons as $btn) {
            $row[] = $btn;
            $i++;
            if ($i % 3 == 0) {
                $keyboard[] = $row;
                $row = [];
            }
        }
        if (!empty($row)) {
            $keyboard[] = $row;
        }
        
        $reply_markup = [
            'keyboard' => $keyboard,
            'resize_keyboard' => true,
            'one_time_keyboard' => true
        ];
        sendMessage($chat_id, $welcomeText, $reply_markup);
    } else {
        // فرض می‌کنیم متن دریافتی یکی از عناوین دکمه‌های اصلی است.
        $stmt = $pdo->prepare("SELECT id FROM main_buttons WHERE title = :title LIMIT 1");
        $stmt->execute([':title' => $text]);
        $main = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($main) {
            // واکشی دکمه‌های اینلاین مرتبط با دکمه اصلی انتخاب‌شده
            $stmt2 = $pdo->prepare("SELECT id, title FROM inline_buttons WHERE main_button_id = :mid ORDER BY title");
            $stmt2->execute([':mid' => $main['id']]);
            $inline_buttons = [];
            while ($row = $stmt2->fetch(PDO::FETCH_ASSOC)) {
                $inline_buttons[] = [
                    'text' => $row['title'],
                    'callback_data' => "ib_" . $row['id']
                ];
            }
            if (!empty($inline_buttons)) {
                // تقسیم دکمه‌ها به ردیف‌های 3تایی
                $inline_keyboard = [];
                $temp = [];
                $i = 0;
                foreach ($inline_buttons as $btn) {
                    $temp[] = $btn;
                    $i++;
                    if ($i % 3 == 0) {
                        $inline_keyboard[] = $temp;
                        $temp = [];
                    }
                }
                if (!empty($temp)) {
                    $inline_keyboard[] = $temp;
                }
                $reply_markup = ['inline_keyboard' => $inline_keyboard];
                $msg = "📚 لطفاً یک گزینه را از زیر منو انتخاب کنید:";
                sendMessage($chat_id, $msg, $reply_markup);
            } else {
                sendMessage($chat_id, "برای این دسته آموزشی زیر منویی تعریف نشده است.");
            }
        } else {
            sendMessage($chat_id, "لطفاً از منوی ارائه‌شده استفاده کنید.");
        }
    }
}

// پردازش callback_query (دکمه‌های اینلاین)
elseif (isset($update['callback_query'])) {
    $callback = $update['callback_query'];
    $chat_id = $callback['message']['chat']['id'];
    $data = $callback['data'];

    if (strpos($data, "ib_") === 0) {
        $inline_button_id = intval(str_replace("ib_", "", $data));
        $stmt = $pdo->prepare("SELECT * FROM files WHERE inline_button_id = :ibid ORDER BY id");
        $stmt->execute([':ibid' => $inline_button_id]);
        $files = $stmt->fetchAll(PDO::FETCH_ASSOC);
        if ($files) {
            foreach ($files as $file) {
                $caption = $file['caption'] ? $file['caption'] : "";
                switch ($file['file_type']) {
                    case 'document':
                        sendDocument($chat_id, $file['file_path'], $caption);
                        break;
                    case 'video':
                        sendVideo($chat_id, $file['file_path'], $caption);
                        break;
                    case 'audio':
                        sendAudio($chat_id, $file['file_path'], $caption);
                        break;
                    case 'text':
                        if (file_exists($file['file_path'])) {
                            $textContent = file_get_contents($file['file_path']);
                            sendMessage($chat_id, $textContent);
                        }
                        break;
                    default:
                        sendDocument($chat_id, $file['file_path'], $caption);
                        break;
                }
            }
        } else {
            sendMessage($chat_id, "فایلی برای این گزینه تعریف نشده است.");
        }
        
        // پاسخ به callback_query جهت از بین بردن حالت بارگذاری در تلگرام
        apiRequest('answerCallbackQuery', ['callback_query_id' => $callback['id']]);
    }
}
?>
