<?php
// telegram_api.php
require_once 'config.php';

/**
 * اجرای درخواست به API تلگرام با استفاده از cURL
 */
function apiRequest($method, $parameters) {
    if (!is_string($method)) {
        error_log("نام متد باید رشته باشد");
        return false;
    }
    if (!$parameters) {
        $parameters = [];
    } elseif (!is_array($parameters)) {
        error_log("پارامترها باید آرایه باشند");
        return false;
    }
    $url = API_URL . $method;
    $handle = curl_init($url);
    curl_setopt($handle, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($handle, CURLOPT_CONNECTTIMEOUT, 5);
    curl_setopt($handle, CURLOPT_TIMEOUT, 60);
    curl_setopt($handle, CURLOPT_POSTFIELDS, $parameters);

    $response = curl_exec($handle);
    if ($response === false) {
        error_log("خطای CURL: " . curl_error($handle));
        curl_close($handle);
        return false;
    }
    $httpCode = curl_getinfo($handle, CURLINFO_HTTP_CODE);
    curl_close($handle);

    if ($httpCode != 200) {
        error_log("خطا در درخواست؛ کد: $httpCode - پاسخ: $response");
        return false;
    }
    return json_decode($response, true);
}

/**
 * ارسال پیام متنی به کاربر
 */
function sendMessage($chat_id, $text, $reply_markup = null, $parse_mode = "HTML") {
    $parameters = [
        'chat_id' => $chat_id,
        'text'    => $text,
        'parse_mode' => $parse_mode,
    ];
    if ($reply_markup) {
        $parameters['reply_markup'] = json_encode($reply_markup);
    }
    return apiRequest('sendMessage', $parameters);
}

/**
 * ارسال سند (document)
 */
function sendDocument($chat_id, $document, $caption = '', $reply_markup = null) {
    $realPath = realpath($document);
    if (!$realPath) {
        error_log("فایل سند پیدا نشد: " . $document);
        return false;
    }
    $parameters = [
        'chat_id' => $chat_id,
        'caption' => $caption,
    ];
    if ($reply_markup) {
        $parameters['reply_markup'] = json_encode($reply_markup);
    }
    
    $url = API_URL . "sendDocument";
    $postFields = $parameters;
    $postFields['document'] = new CURLFile($realPath);
    
    $ch = curl_init(); 
    curl_setopt($ch, CURLOPT_HTTPHEADER, ["Content-Type: multipart/form-data"]);
    curl_setopt($ch, CURLOPT_URL, $url); 
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); 
    curl_setopt($ch, CURLOPT_POSTFIELDS, $postFields); 
    $output = curl_exec($ch);
    if ($output === false) {
        error_log("خطای ارسال سند: " . curl_error($ch));
    }
    curl_close($ch);
    
    return $output;
}

/**
 * ارسال ویدیو
 */
function sendVideo($chat_id, $video, $caption = '', $reply_markup = null) {
    $realPath = realpath($video);
    if (!$realPath) {
        error_log("فایل ویدیو پیدا نشد: " . $video);
        return false;
    }
    $parameters = [
        'chat_id' => $chat_id,
        'caption' => $caption,
    ];
    if ($reply_markup) {
        $parameters['reply_markup'] = json_encode($reply_markup);
    }
    
    $url = API_URL . "sendVideo";
    $postFields = $parameters;
    $postFields['video'] = new CURLFile($realPath);
    
    $ch = curl_init(); 
    curl_setopt($ch, CURLOPT_HTTPHEADER, ["Content-Type: multipart/form-data"]);
    curl_setopt($ch, CURLOPT_URL, $url); 
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); 
    curl_setopt($ch, CURLOPT_POSTFIELDS, $postFields); 
    $output = curl_exec($ch);
    if ($output === false) {
        error_log("خطای ارسال ویدیو: " . curl_error($ch));
    }
    curl_close($ch);
    
    return $output;
}

/**
 * ارسال صوت (audio)
 */
function sendAudio($chat_id, $audio, $caption = '', $reply_markup = null) {
    $realPath = realpath($audio);
    if (!$realPath) {
        error_log("فایل صوت پیدا نشد: " . $audio);
        return false;
    }
    $parameters = [
        'chat_id' => $chat_id,
        'caption' => $caption,
    ];
    if ($reply_markup) {
        $parameters['reply_markup'] = json_encode($reply_markup);
    }
    
    $url = API_URL . "sendAudio";
    $postFields = $parameters;
    $postFields['audio'] = new CURLFile($realPath);
    
    $ch = curl_init(); 
    curl_setopt($ch, CURLOPT_HTTPHEADER, ["Content-Type: multipart/form-data"]);
    curl_setopt($ch, CURLOPT_URL, $url); 
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); 
    curl_setopt($ch, CURLOPT_POSTFIELDS, $postFields); 
    $output = curl_exec($ch);
    if ($output === false) {
        error_log("خطای ارسال صوت: " . curl_error($ch));
    }
    curl_close($ch);
    
    return $output;
}
?>
