from telegram import Update
from telegram.ext import CallbackContext
from db import get_user_details, get_all
from telegram import Update
from telegram.ext import CallbackContext, ConversationHandler
from telegram import InlineKeyboardButton, InlineKeyboardMarkup
from logging_script import logger
from db import revoke_all_permissions, set_user_permissions, has_permission
from config import ADMIN_IDs
from config import ACCESS,FILTER_SELECTION, FILTER_CONFIRMATION, filters_list





async def report(update: Update, context: CallbackContext):
    permissions = get_all()

    ans = "آیدی هایی که اجازه دسترسی به ربات دارند:\n\n"
    for user_id in permissions:
        _, x,y,z,f, count = get_user_details(user_id)
        ans += str(user_id) + f"  تعداد آگهی مشاهده شده:  {count} " + "\n\n"

    await update.message.reply_text(ans)

async def report_permissions(update: Update, context: CallbackContext):
    permissions = get_all()

    ans = "آیدی هایی که اجازه دسترسی به ربات دارند:\n"
    ans += "\n".join([f"{j+1}) {i}" for j, i in enumerate(filters_list)])
    for user_id in permissions:
        _, x,y,z,f, count = get_user_details(user_id)
        ans += "\n"
        ans += f"\n{user_id}:"
        if x:
            ans += " 1 "
        if y:
            ans += " 2 "
        if z:
            ans += " 3 "
        if f:
            ans += " 4 "

    await update.message.reply_text(ans)

    
async def admin_message_handler(update: Update, context: CallbackContext):
    user = update.message.from_user
    if not user["id"] in ADMIN_IDs:
        return ConversationHandler.END

    if update.message.text == "گزارش📈":
        await report(update, context)
    elif update.message.text == "گزارش دسترسی ها📈":
        await report_permissions(update, context)
    elif update.message.text == "افزودن دسترسی➕":
        await add_access_start(update, context)
        return ACCESS
    elif update.message.text == "حذف دسترسی🔒":
        
        await remove_access_start(update, context)
        return ACCESS

async def add_access_start(update: Update, context: CallbackContext) -> int:
    user = update.message.from_user
    logger.info("User(Admin) %s clicked on Add Access", user.first_name)
    await update.message.reply_text(
        "لطفاً شناسه کاربری که می‌خواهید دسترسی بدهید را با علامت مثبت ابتدای آن وارد کنید: \n"
        "(برای لغو عملیت کلمه 'برگشت' را بفرستید)"
    )
    logger.info("Waiting for user ID input.")
    return ACCESS


async def access_handler(update: Update, context: CallbackContext) -> int:
    user = update.message.from_user
    if not user["id"] in ADMIN_IDs:
        return ConversationHandler.END
    user_id = str(update.message.text)
    logger.info("Received user ID: %s", user_id)
    if user_id[0] == "+":
        context.user_data["user_id_to_add"] = int(user_id[1:])
        context.user_data[(int(user_id[1:]))] = []
        keyboard = [[InlineKeyboardButton(f, callback_data=f)] for f in filters_list]
        reply_markup = InlineKeyboardMarkup(keyboard)
        await update.message.reply_text(
            "لطفاً فیلترهای مورد نظر خود را انتخاب کنید (یکی یکی):",
            reply_markup=reply_markup
        )
        return FILTER_SELECTION
    elif user_id[0] == "-":
        if has_permission(user_id[1:]):
            context.user_data[(int(user_id[1:]))] = []
            context.user_data["user_id_to_add"] = None
            revoke_all_permissions(int(user_id[1:]))
            logger.info("Removed access from user ID: %s", user_id)
            await update.message.reply_text(f"دسترسی از کاربر {user_id[1:]} گرفته شد.")
            return ConversationHandler.END
        else:
            await update.message.reply_text(f"این آیدی از قبل دسترسی نداشته!")
            return ConversationHandler.END
    else:
        await update.message.reply_text(f"ورودی نامعتبر! \nلطفا از قاعده گفته شده پیروی کنید.")


async def filter_selection(update: Update, context: CallbackContext) -> int:
    query = update.callback_query
    await query.answer()
    selected_filter = query.data

    
    user_id = context.user_data["user_id_to_add"]
    if user_id not in context.user_data:
        context.user_data[user_id] = []
    context.user_data[user_id].append(selected_filter)

    if "تایید" not in context.user_data[user_id]:
        remaining_filters = [f for f in filters_list]
        keyboard = [[InlineKeyboardButton(f+"❌", callback_data=f)] if f not in context.user_data[user_id] else [InlineKeyboardButton(f+"✅", callback_data=f)] for f in remaining_filters] + [[InlineKeyboardButton("تایید", callback_data="تایید")]]
        reply_markup = InlineKeyboardMarkup(keyboard)
        await query.edit_message_text(
            "لطفاً فیلترهای دیگر خود را انتخاب کنید:",
            reply_markup=reply_markup
        )
        return FILTER_SELECTION
    else:
        keyboard = [[InlineKeyboardButton("تایید", callback_data="confirm")]]
        reply_markup = InlineKeyboardMarkup(keyboard)
        context.user_data[user_id].pop()
        await query.edit_message_text(
            f"فیلترهای انتخاب شده: {', '.join(context.user_data[user_id])}.\n"
            "لطفاً تایید کنید.",
            reply_markup=reply_markup
        )
        return FILTER_CONFIRMATION

async def filter_confirmation(update: Update, context: CallbackContext) -> int:
    query = update.callback_query
    await query.answer()
    user_id = context.user_data["user_id_to_add"]

    filters_dict = {}
    for i in filters_list:
        if i in context.user_data[user_id]:
            filters_dict[i] = 1
        else:
            filters_dict[i] = 0

    if query.data == "confirm":
        if not has_permission(user_id):
            set_user_permissions(user_id,  filters_dict["خرید و فروش مسکونی"],
                                filters_dict["رهن و اجاره مسکونی"], 
                                filters_dict["خرید و فروش اداری و تجاری"],
                                filters_dict["رهن و اجاره اداری و تجاری"],
                                 0)
            logger.info("Granted access to user ID: %s with filters: %s", user_id, context.user_data[user_id])
            await query.edit_message_text(f"دسترسی به کاربر {user_id} با فیلترهای {', '.join(context.user_data[user_id])} اعطا شد.")
        else:
            set_user_permissions(user_id,  filters_dict["خرید و فروش مسکونی"],
                                filters_dict["رهن و اجاره مسکونی"], 
                                filters_dict["خرید و فروش اداری و تجاری"],
                                filters_dict["رهن و اجاره اداری و تجاری"],
                                 0)
            await query.edit_message_text(f"این کاربر از قبل دسترسی داشته. دسترسی‌های جدید برای این کاربر تعیین شد.")
    
    return ConversationHandler.END


async def remove_access_start(update: Update, context: CallbackContext) -> int:
    user = update.message.from_user
    logger.info("User(Admin) %s clicked on Remove Access", user.first_name)
    await update.message.reply_text("لطفاً شناسه کاربری که می‌خواهید دسترسی‌اش را از بین ببرید را با علامت منفی ابتدای آن وارد کنید: \n(برای لغو عملیت کلمه 'برگشت' را بفرستید)")
    logger.info("Waiting for user ID input.")
    return ACCESS


async def cancel_handler(update: Update, context: CallbackContext) -> int:
    logger.info("Operation canceled by user.")
    await update.message.reply_text("عملیات لغو شد.")
    return ConversationHandler.END
